pub struct Document {
    pub blocks: Blocks,
    pub config: Config,
    pub macros: Vec<String>,
    pub variables: Vec<String>,
    pub metadata: Vec<Metadata>,
    pub resources: Vec<String>,
}
Struct representing a Unimarkup document

Fields

blocks: Blocks

Blocks of this Unimarkup document

config: Config

Configuration used to create this Unimarkup document

macros: Vec<String>

Field containing all macros defined in this Unimarkup document

variables: Vec<String>

Field containing all variables defined in this Unimarkup document

metadata: Vec<Metadata>

Field containing metadata for this Unimarkup document

resources: Vec<String>

Field containing all external resources used in this Unimarkup document

Implementations

source

impl Document

source

pub fn html(&self) -> Html

Returns the HTML representation of this Unimarkup document

source

pub fn output_formats(&self) -> Option<&Vec<OutputFormat>>

Returns the configured output formats for this Unimarkup document